@@ -39,9 +39,10 @@ options:
     -f, --format=<format>...     Only only delete files matching the specified format(s).
     -R, --retries=<i>            Number of times to retry if S3 returns a 503 SlowDown
                                  error [default: 2].
+    -n, --no-backup              Don't move deleted files to the history subdirectory.
 
 examples:
-    ia delete <id> <file> -H x-archive-keep-old-version:0  # Turn off backups
+    ia delete <id> <file> --no-backup  # Turn off backups
 """
 from __future__ import absolute_import, print_function, unicode_literals
 
@@ -93,10 +94,13 @@ def main(argv, session):
 
     # Add keep-old-version by default.
     if 'x-archive-keep-old-version' not in args['--header']:
-        args['--header']['x-archive-keep-old-version'] = '1'
+        if args['--no-backup']:
+            args['--header']['x-archive-keep-old-version'] = '0'
+        else:
+            args['--header']['x-archive-keep-old-version'] = '1'
 
     if verbose:
-        sys.stdout.write('Deleting files from {0}\n'.format(item.identifier))
+        print('Deleting files from {0}'.format(item.identifier))
 
     if args['--all']:
         files = [f for f in item.get_files()]
@@ -118,7 +122,7 @@ def main(argv, session):
         files = list(item.get_files(fnames))
 
     if not files:
-        sys.stderr.write(' warning: no files found, nothing deleted.\n')
+        print(' warning: no files found, nothing deleted.', file=sys.stderr)
         sys.exit(1)
 
     errors = False
@@ -126,13 +130,12 @@ def main(argv, session):
     for f in files:
         if not f:
             if verbose:
-                sys.stderr.write(' error: "{0}" does not exist\n'.format(f.name))
+                print(' error: "{0}" does not exist'.format(f.name), file=sys.stderr)
             errors = True
         if any(f.name.endswith(s) for s in no_delete):
             continue
         if args['--dry-run']:
-            sys.stdout.write(' will delete: {0}/{1}\n'.format(item.identifier,
-                                                              f.name.encode('utf-8')))
+            print(' will delete: {0}/{1}'.format(item.identifier, f.name))
             continue
         try:
             resp = f.delete(verbose=verbose,
