@@ -101,6 +101,20 @@ def remove_metadata(item, metadata, args):
             print('{0}/metadata/{1} does not exist, skipping.'.format(
                 item.identifier, key), file=sys.stderr)
             continue
+        elif key == 'collection' and metadata[key] not in src_md:
+            r = item.remove_from_simplelist(metadata[key], 'holdings')
+            j = r.json()
+            if j.get('success'):
+                print('{} - success: {} no longer in {}'.format(
+                      item.identifier, item.identifier, metadata[key]))
+                sys.exit(0)
+            elif j.get('error', '').startswith('no row to delete for'):
+                print('{} - success: {} no longer in {}'.format(
+                      item.identifier, item.identifier, metadata[key]))
+                sys.exit(0)
+            else:
+                print('{} - error: {}'.format(item.identifier, j.get('error')))
+            sys.exit()
         elif not isinstance(src_md, list):
             if key == 'subject':
                 src_md = src_md.split(';')
