@@ -32,6 +32,7 @@ import logging
 import socket
 
 import six.moves.urllib as urllib
+import six
 from requests.exceptions import HTTPError, RetryError, ConnectTimeout, \
     ConnectionError, ReadTimeout
 
@@ -109,14 +110,20 @@ class File(BaseFile):
         :param file_metadata: (optional) a dict of metadata for the
                               given fille.
         """
+        if six.PY2:
+            try:
+                name = name.decode('utf-8')
+            except UnicodeEncodeError:
+                pass
         super(File, self).__init__(item.item_metadata, name, file_metadata)
         self.item = item
         url_parts = dict(
             protocol=item.session.protocol,
             id=self.identifier,
             name=urllib.parse.quote(name.encode('utf-8')),
+            host=item.session.host,
         )
-        self.url = '{protocol}//archive.org/download/{id}/{name}'.format(**url_parts)
+        self.url = '{protocol}//{host}/download/{id}/{name}'.format(**url_parts)
         if self.item.session.access_key and self.item.session.secret_key:
             self.auth = auth.S3Auth(self.item.session.access_key,
                                     self.item.session.secret_key)
@@ -344,7 +351,7 @@ class File(BaseFile):
 
         url = '{0}//s3.us.archive.org/{1}/{2}'.format(self.item.session.protocol,
                                                       self.identifier,
-                                                      self.name)
+                                                      urllib.parse.quote(self.name))
         self.item.session.mount_http_adapter(max_retries=max_retries,
                                              status_forcelist=[503],
                                              host='s3.us.archive.org')
