@@ -743,6 +743,7 @@ class Item(BaseItem):
     def upload_file(self, body,
                     key=None,
                     metadata=None,
+                    file_metadata=None,
                     headers=None,
                     access_key=None,
                     secret_key=None,
@@ -767,6 +768,11 @@ class Item(BaseItem):
         :type metadata: dict
         :param metadata: (optional) Metadata used to create a new item.
 
+        :type file_metadata: dict
+        :param file_metadata: (optional) File-level metadata to add to
+                              the files.xml entry for the file being
+                              uploaded.
+
         :type headers: dict
         :param headers: (optional) Add additional IA-S3 headers to request.
 
@@ -811,6 +817,7 @@ class Item(BaseItem):
         # Set defaults.
         headers = {} if headers is None else headers
         metadata = {} if metadata is None else metadata
+        file_metadata = {} if file_metadata is None else file_metadata
         access_key = self.session.access_key if access_key is None else access_key
         secret_key = self.session.secret_key if secret_key is None else secret_key
         queue_derive = True if queue_derive is None else queue_derive
@@ -827,6 +834,8 @@ class Item(BaseItem):
             request_kwargs['timeout'] = 120
         md5_sum = None
 
+        _headers = headers.copy()
+
         if not hasattr(body, 'read'):
             filename = body
             body = open(body, 'rb')
@@ -840,10 +849,10 @@ class Item(BaseItem):
 
         # Support for uploading empty files.
         if size == 0:
-            headers['Content-Length'] = '0'
+            _headers['Content-Length'] = '0'
 
-        if not headers.get('x-archive-size-hint'):
-            headers['x-archive-size-hint'] = str(size)
+        if not _headers.get('x-archive-size-hint'):
+            _headers['x-archive-size-hint'] = str(size)
 
         # Build IA-S3 URL.
         key = norm_filepath(filename).split('/')[-1] if key is None else key
@@ -877,7 +886,7 @@ class Item(BaseItem):
         if verify or delete:
             if not md5_sum:
                 md5_sum = get_md5(body)
-            headers['Content-MD5'] = md5_sum
+            _headers['Content-MD5'] = md5_sum
 
         def _build_request():
             body.seek(0, os.SEEK_SET)
@@ -903,12 +912,13 @@ class Item(BaseItem):
             else:
                 data = body
 
-            headers.update(self.session.headers)
+            _headers.update(self.session.headers)
             request = S3Request(method='PUT',
                                 url=url,
-                                headers=headers,
+                                headers=_headers,
                                 data=data,
                                 metadata=metadata,
+                                file_metadata=file_metadata,
                                 access_key=access_key,
                                 secret_key=secret_key,
                                 queue_derive=queue_derive)
@@ -964,11 +974,9 @@ class Item(BaseItem):
                         'local copy'.format(i=self.identifier, f=key))
                     body.close()
                     os.remove(filename)
-                body.close()
                 response.close()
                 return response
             except HTTPError as exc:
-                body.close()
                 msg = get_s3_xml_text(exc.response.content)
                 error_msg = (' error uploading {0} to {1}, '
                              '{2}'.format(key, self.identifier, msg))
@@ -977,6 +985,8 @@ class Item(BaseItem):
                     print(' error uploading {0}: {1}'.format(key, msg), file=sys.stderr)
                 # Raise HTTPError with error message.
                 raise type(exc)(error_msg, response=exc.response, request=exc.request)
+            finally:
+                body.close()
 
     def upload(self, files,
                metadata=None,
@@ -1035,18 +1045,32 @@ class Item(BaseItem):
         """
         queue_derive = True if queue_derive is None else queue_derive
         remote_dir_name = None
+        total_files = None
         if isinstance(files, dict):
-            files = list(files.items())
+            if files.get('name'):
+                files = [files]
+                total_files = 1
+            else:
+                files = list(files.items())
         if not isinstance(files, (list, tuple)):
             files = [files]
+        if all(isinstance(f, dict) and f.get('name') for f in files):
+            total_files = len(files)
 
         responses = []
         file_index = 0
-        if checksum:
-            total_files = recursive_file_count(files, item=self, checksum=True)
-        else:
-            total_files = recursive_file_count(files, item=self, checksum=False)
+        if queue_derive and total_files is None:
+            if checksum:
+                total_files = recursive_file_count(files, item=self, checksum=True)
+            else:
+                total_files = recursive_file_count(files, item=self, checksum=False)
+        file_metadata = None
         for f in files:
+            if isinstance(f, dict):
+                if f.get('name'):
+                    file_metadata = f.copy()
+                    del file_metadata['name']
+                    f = f['name']
             if (isinstance(f, string_types) and is_dir(f)) \
                     or (isinstance(f, tuple) and is_dir(f[-1])):
                 if isinstance(f, tuple):
@@ -1071,6 +1095,7 @@ class Item(BaseItem):
                     resp = self.upload_file(filepath,
                                             key=key,
                                             metadata=metadata,
+                                            file_metadata=file_metadata,
                                             headers=headers,
                                             access_key=access_key,
                                             secret_key=secret_key,
@@ -1103,6 +1128,7 @@ class Item(BaseItem):
                 resp = self.upload_file(body,
                                         key=key,
                                         metadata=metadata,
+                                        file_metadata=file_metadata,
                                         headers=headers,
                                         access_key=access_key,
                                         secret_key=secret_key,
